#
# spec file for package grpc
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname libgrpc6
%define src_install_dir /usr/src/%{name}
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           grpc
Version:        1.16
Release:        lp151.3.4
%define rver	1.16.0
Summary:        HTTP/2-based Remote Procedure Call implementation
License:        Apache-2.0
Group:          Development/Tools/Building
Url:            http://grpc.io/
Source:         https://github.com/grpc/grpc/archive/v%rver.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libcares)
BuildRequires:  pkgconfig(openssl) >= 1.0.1
BuildRequires:  pkgconfig(protobuf) >= 3.5
BuildRequires:  pkgconfig(zlib)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The reference implementation of the gRPC protocol, done on top of
HTTP/2 with support for synchronous and asynchronous calls. gRPC uses
Protocol Buffers as the Interface Definition Language by default.

%package -n %lname
Summary:        HTTP/2-based Remote Procedure Call implementation
Group:          System/Libraries

%description -n %lname
The reference implementation of the gRPC protocol, done on top of
HTTP/2 with support for synchronous and asynchronous calls. gRPC uses
Protocol Buffers as the Interface Definition Language by default.

%package devel
Summary:        Development files for grpc, a HTTP/2 Remote Procedure Call implementation
Group:          Development/Tools/Building
Requires:       %lname = %version

%description devel
This subpackage contains libraries and header files for developing
applications that want to make use of the gRPC reference implementation.

%package source
Summary:        Source code of gRPC
Group:          Development/sources
BuildArch:      noarch

%description -n grpc-source
This subpackage contains source code of the gRPC reference implementation.

%package -n python2-grpcio
Summary:        Python language bindings for grpc, a HTTP/2 Remote Procedure Call implementation
Group:          Development/Libraries/Python
Requires:       %lname = %version-%release
Requires:       python = %python2_version

%description -n python2-grpcio
This subpackage contains the python2 bindings.

%package -n python3-grpcio
Summary:        Python language bindings for grpc, a HTTP/2 Remote Procedure Call implementation
Group:          Development/Libraries/Python
Requires:       %lname = %version-%release
Requires:       python = %python3_version

%description -n python3-grpcio
This subpackage contains the python3 bindings.

%prep
%setup -qn grpc-%rver

%build
make %{?_smp_mflags} STRIP=/bin/true V=1 VERBOSE=1 \
	CFLAGS="%optflags -Wno-error" CXXFLAGS="%optflags -Wno-error"

# build python module
export GRPC_PYTHON_BUILD_WITH_CYTHON=True
export GRPC_PYTHON_BUILD_SYSTEM_OPENSSL=True
export GRPC_PYTHON_BUILD_SYSTEM_ZLIB=True
export GRPC_PYTHON_BUILD_SYSTEM_CARES=True
export CFLAGS="%optflags"
%python_build

%install
b="%buildroot"
%make_install prefix="$b/%_prefix" STRIP=/bin/true V=1 VERBOSE=1
find "$b/%_includedir" -type f -exec chmod a-x {} +
pushd "$b/usr"
rm -fv lib/*.a share/grpc/*.pem
perl -i -pe 's{^prefix=.*}{prefix=%_prefix}' lib/pkgconfig/*.pc
perl -i -pe 's{^libdir=.*}{libdir=%_libdir}' lib/pkgconfig/*.pc
if test ! -d lib64 && test "%_lib" = lib64; then
	mv lib lib64
fi
popd
%python_install

# Install sources
mkdir -p %{buildroot}%{src_install_dir}
tar -xzf %{SOURCE0} --strip-components=1 -C %{buildroot}%{src_install_dir}
# Fix env-script-interpreter rpmlint error
find %{buildroot}%{src_install_dir} -type f -exec sed -i 's|#!/usr/bin/env bash|#!/bin/bash|' "{}" +
find %{buildroot}%{src_install_dir} -type f -exec sed -i 's|#!/usr/bin/env ruby|#!/usr/bin/ruby|' "{}" +
find %{buildroot}%{src_install_dir} -type f \( -name "*.bzl" -o -name "*.py" \) -exec sed -i 's|#!/usr/bin/env python2.7|#!/usr/bin/python2.7|' "{}" +
find %{buildroot}%{src_install_dir} -type f \( -name "*.bzl" -o -name "*.py" \) -exec sed -i 's|#!/usr/bin/env python|#!/usr/bin/python|' "{}" +

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%_libdir/libaddress_sorting.so.*
%_libdir/libgpr*.so.*
%_libdir/libgrpc*.so.*

%files devel
%defattr(-,root,root)
%license LICENSE
%_bindir/*
%_includedir/*
%_libdir/pkgconfig/*.pc
%_libdir/*.so

%files source
%{src_install_dir}

%files -n python2-grpcio
%python2_sitearch/grpcio-%rver-py*.egg-info
%python2_sitearch/grpc

%files -n python3-grpcio
%python3_sitearch/grpcio-%rver-py*.egg-info
%python3_sitearch/grpc

%changelog
* Mon Jan  7 2019 Michał Rostecki <mrostecki@suse.de>
- Add grpc-source package - some Go programs using gRPC need
  protobuf definitions which are included inside the source code,
  but are not included in the devel package.
* Sun Nov 11 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.16
  * Keepalive watchdog firing should return status UNAVAILABLE.
  * Set TCP_USER_TIMEOUT socket option for Linux.
  * Turn loading system root certificate as default.
  * Change pick_first to not unref unselected subchannels.
  * cmake: prevent C core from depending on libstdc++.
  * Implement Watch method in health check service.
* Sun Nov 11 2018 Thomas Bechtold <tbechtold@suse.com>
- update to 1.15.1:
  * Document SSL portability and performance considerations. See
    https://github.com/grpc/grpc/blob/master/doc/ssl-performance.md .
  * Simplify call arena size growth.
  * PF: Check connectivity state before watching.
  * Added system roots feature to load roots from OS trust store.
  * Fix re-resolution in pick first.
  * Allow error strings in final_info to propagate to filters on
    call destruction.
  * Add resolver executor.
  * Data race fix for lockfree_event.
  * Channelz: Expose new Core API.
  * cmake: disable assembly optimizations only when necessary.
  * C++ sync server: Return status RESOURCE_EXHAUSTED if no
    thread quota available.
  * Use correct target name for gflags-config.cmake.
  * Make should generate pkg-config file for gpr as well.
  * Restrict the number of threads in C++ sync server.
  * Allow reset of connection backoff.
- update to 1.14.2:
  * Add TROUBLESHOOTING.md guide
  * Fixed gRPC channels blocking indefinitely and not respecting
    deadlines on network disconnect.
  * Add user guide for keepalive.
  * Fix GRPC_ARG_HTTP2_MIN_RECV_PING_INTERVAL_WITHOUT_DATA_MS doc
    to restrict usage to server.
  * Fixed ordering in adding pending picks to Round Robin LB.
  * Implement local channel/server credentials for UDS connections.
  * Allow extra copy in zero-copy protector integrity-only mode.
  * Update to use the canonical version of LB proto.
  * Prefer using https_proxy over http_proxy.
  * Refactor to put c-ares queries under a combiner.
  * Remove already_closed parameter from fd_orphan.
  * Add channel arg to enable/disable http proxy.
  * Fix shutdown of closed fd when c-ares opens a second fd.
  * Fixed segmentation fault when product name from BIOS is empty.
  * Introduce server-side load reporting service.
  * Reorder steps in ServerBuilder::BuildAndStart().
  * Support Per-Method Codegen Generic on Server Side.
  * Protobuf-related headers are available in a subspec of
    gRPC-C++ podspec.
- update to 1.13.1:
  * gRPC stats will only be collected for debug builds or if
    GRPC_COLLECT_STATS is defined. It will be disabled for opt
    builds.
  * Fix for Issue #13553. Unlimited can now be set as the max
    receive message length.
  * cmake install now also installs should also installs the
    roots.pem file.
- Drop 0001-Allow-building-the-python-module-with-system-openssl.patch
  Applied upstream
- Drop 0002-Allow-building-the-python-module-with-system-zlib.patch
  Applied upstream
- 0003-Allow-building-the-python-module-with-system-cares.patch
  Applied upstream
* Sat Jun 23 2018 jengelh@inai.de
- Throw out silly -Werror in release builds.
* Fri May 25 2018 tbechtold@suse.com
- build grpc python module for python2 and python3
  * add 0001-Allow-building-the-python-module-with-system-openssl.patch
  * add 0002-Allow-building-the-python-module-with-system-zlib.patch
  * add 0003-Allow-building-the-python-module-with-system-cares.patch
* Fri May 18 2018 jengelh@inai.de
- Switch to plain makefiles since they generate more shared libs.
- Remove grpc-build.diff, grpc-versioning.diff.
* Fri May 18 2018 tbechtold@suse.com
- update to 1.12.0:
  Core:
  * Update protobuf submodule to 3.5.2 (#15114)
  * Make GrpcBuffer{Reader|Writer} Public (#14541)
  * Compile Out Tracers Option (#15108)
  * Fix bug in an address sorting comparison (#15208)
  * Fix: Check retry timer before starting resolving (#15156)
  * Fix c-ares resolution with default authority (#15073)
  * Fix c-ares resolver crash when DNS server unreachable (#15134)
  * Performance: Avoid low severity log message construction (#14945)
  * Peformance: Enable SIO_LOOPBACK_FAST_PATH on Windows (#14905)
  C#:
  * Add RpcException.StatusCode property (#15140)
  * Improvements to C# build instructions (#15178)
  Python:
  * Eliminate grpcio package dependency on protobuf package (#15034).
    Please pay extra attention if you are using gRPC with Protocol Buffers and
    your deployment scripts do not explicitly list the correct dependencies
    and used to rely on the transitive Python package dependency from grpcio to protobuf.
  * A new grpc.Channel.close method is introduced and correct use of gRPC
    Python now requires that channels be closed after use. No existing code
    should observably break when upgrading to 1.12 but code that creates
    channels but does not close them will not be supported in 1.13 and later.
  Core:
  * Fix: Check retry timer before starting resolving (#15156)
  * Fix c-ares resolution with default authority (#15073)
  * Fix c-ares resolver crash when DNS server unreachable (#15134)
  * Add core underpinnings for TLS session ticket support (#14483)
  * Experimental support for configurable retries (use at your own risk) (#10684)
  * Fail calls with wait_for_ready=false on transient resolver failure (#14733)
  * Fix a call stack ref flake (#14681)
  * c-ares DNS resolver sorts resolved addresses per RFC 6724 (#13290)
  * Use socklen_t instead of size_t for address length (fixes use case for some
    big endian systems) (#14464)
  * Initial part of channel tracing implementation (#13883, #14746, #14751)
  * Avoid crashes on environments with hot-plugged CPUs (#14712)
  * When building from source, Makefile now checks for minimum protobuf
    version 3.5.0 instead 3.0.0 (#14821)
  * gRPC Core public header no longer includes inttypes.h (#14676)
  * CMake improvements:
  * Add well-commented examples and continuous test for various ways of
    building gRPC as a dependency (via ExternalProject_Add in #14822,
    via add_subdirectory in #14864)
  * Remove internal tools from binaries installed by cmake install (#14850)
  * Simplify Android build example (#14885)
  * Enable SO_REUSEPORT in IPv6-only environments as well (#14748)
  C#:
  * Improvements in experimental support for Unity - added useful resources
    and improved support for loading grpc_csharp_ext on Unity (#14576, #14605)
  * Further prevent name collisions by using only fully qualified type
    names in C# code generator (#14524)
  * Fix C# connectivity watcher shutdown race (#14776)
  Objective-C:
  * Support for Keep-Alive (#14781)
  * Experimental C++ podspec now supports Apple framework (#14480)
  * Allow discarding generated implementation (leaving only protocol)
    with macro (#14490)
  * Better handling of network error (#14554)
  PHP:
  * Add missing -O2 compilation flag for pecl (#14768)
  * Update the reserved variable list to check in PHP code generator to
    match protobuf 3.5.0 (#13580)
  Python:
  * Progress towards full Beta API elimination (Beta API is and has been
    unsupported and will go away completely):
    Remove _face_interface_test tests for the Beta API (#14702)
  * Remove Python background poller thread (#14448)
    Note there is a small change in behavior. Before, clients would
    detect disconnected channels immediately.
  * Initial gevent compatibility (EXPERIMENTAL) (#14561)
  * Release the GIL when calling grpc_call_start_batch to improve
    performance under multithreaded scenarios. (#14801)
  Ruby:
  * Correct handling of underscores in package names by Protocol Buffers code
    generator for Ruby (#13634)
  * Source code and locally compiled (not cross-compiled) shared libraries
    (grpc_c.so files) are removed from the linux binary packages. This includes
    the packages targeting the x86_64-linux and x86-linux platforms (#14634)
  * Bug fix for a use-after-free related to access to a garbage collected
    object (#14809)
  * Get rid of the -Wno-format argument to compilation of the ruby extension
  * Documentation improvements (#14535)
  * Don’t raise GRPC::Core::CallErrors for failed reads or writes of bidi
    streaming calls (#14922)
  * Fix a race condition in an interrupt handler that could cause an
    assertion failure (#14953)
* Wed Mar 28 2018 jengelh@inai.de
- Update to new upstream release 1.10.0
  * Several features of core have been removed from the surface
    or GPR API as they were not used in any wrapped language
    (except C++) or in external applications.
  * Changed resolver and LB policy APIs to C++
  * C++ headers are moved from <grpc++/> to <grpcpp/>.
* Mon Feb  5 2018 jengelh@inai.de
- Update to new upstream release 1.9.0
  * LB policies request re-resolution without shutting down
  * On server, include receiving HTTP/2 settings in handshake
    timeout.
  * Add thread naming support on platforms that support it.
* Tue Jan 30 2018 jengelh@inai.de
- Update to new upstream release 1.8.6
  * Fix server segfault on invalid HTTP/2
* Fri Jan 19 2018 jengelh@inai.de
- Update to new upstream release 1.8.5
  * Fix a couple of memory leak issues in the PHP parts
* Tue Jan 16 2018 jengelh@inai.de
- Update to new upstream release 1.8.4
  * Fix HTTP/2 PING issues
  * Fix issues with poll engine
* Tue Jan  2 2018 crrodriguez@opensuse.org
- version 1.8.3
  * Eliminate superfluous log error messages
* Thu Dec 21 2017 jengelh@inai.de
- Update to new upstream release 1.8.2
  * Several LB policies fixes (grpclb and pick_first)
* Mon Dec 11 2017 jengelh@inai.de
- Update to new upstream release 1.7.3
  * Bugfixes in Load Balancing policies
  * Add flow-control and bugfixes to in-process transport
  * (C++) Async API extensions to improve multithreading support
    and reduce the need for explicit synchronization
  * (C++) Unary call API for generic (non-protobuf) RPCs
- Drop grpc-zlib.diff, grpc-protobuf.diff (fix included upstream)
- Add grpc-build.diff
* Wed Apr 19 2017 jengelh@inai.de
- Initial package (version 1.2.3) for build.opensuse.org
